HRQoL: HRQoL regression coefficients (Sweden and Denmark)

HRQoLR Documentation

HRQoL regression coefficients (Sweden and Denmark)

Description

The object contains two elements, "Sweden" and "Denmark". Each element is a matrix with one row per contrast and the columns coef, lower, and upper.

Age is modelled using a spline in the underlying regression model and is therefore presented as a contrast (e.g. "85 vs 65 years") rather than a single linear effect.

Usage

HRQoL

Format

A named list with two matrices (Sweden, Denmark). Each matrix has 4 rows and 3 columns:

  • coef: Estimated regression coefficient (beta).

  • lower: Lower 95% confidence bound.

  • upper: Upper 95% confidence bound.

Details

A list of regression coefficients with 95\ health-related quality of life (HRQoL) 1 year after total hip arthroplasty.

Gordon M, Paulsen A, Overgaard S, Garellick G, Pedersen AB, Rolfson O. Factors influencing health-related quality of life after total hip replacement

  • a comparison of data from the Swedish and Danish hip arthroplasty registers. BMC Musculoskelet Disord. 2013;14:316. doi:10.1186/1471-2474-14-316. PubMed PMID: 24192304.

Examples

data(HRQoL)
names(HRQoL)
HRQoL$Sweden
HRQoL$Denmark

forestplot documentation built on March 4, 2026, 9:06 a.m.