| HRQoL | R Documentation |
The object contains two elements, "Sweden" and "Denmark".
Each element is a matrix with one row per contrast and the columns
coef, lower, and upper.
Age is modelled using a spline in the underlying regression model and is therefore presented as a contrast (e.g. "85 vs 65 years") rather than a single linear effect.
HRQoL
A named list with two matrices (Sweden, Denmark).
Each matrix has 4 rows and 3 columns:
coef: Estimated regression coefficient (beta).
lower: Lower 95% confidence bound.
upper: Upper 95% confidence bound.
A list of regression coefficients with 95\ health-related quality of life (HRQoL) 1 year after total hip arthroplasty.
Gordon M, Paulsen A, Overgaard S, Garellick G, Pedersen AB, Rolfson O. Factors influencing health-related quality of life after total hip replacement
a comparison of data from the Swedish and Danish hip arthroplasty registers. BMC Musculoskelet Disord. 2013;14:316. doi:10.1186/1471-2474-14-316. PubMed PMID: 24192304.
data(HRQoL)
names(HRQoL)
HRQoL$Sweden
HRQoL$Denmark
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.