| dfHRQoL | R Documentation |
The data frame includes a textual label for each contrast and columns for the estimate and its 95\ be used for faceting or subgroup styling.
dfHRQoL
A data frame with 8 rows and 5 variables:
labeltext: Contrast label (character).
mean: Estimated regression coefficient (beta) (numeric).
lower: Lower 95% confidence bound (numeric).
upper: Upper 95% confidence bound (numeric).
group: Country/group label (character).
A long-format data frame version of HRQoL with one row per
contrast and country, intended for plotting (e.g. forest plots).
Gordon M, Paulsen A, Overgaard S, Garellick G, Pedersen AB, Rolfson O. Factors influencing health-related quality of life after total hip replacement
a comparison of data from the Swedish and Danish hip arthroplasty registers. BMC Musculoskelet Disord. 2013;14:316. doi:10.1186/1471-2474-14-316. PubMed PMID: 24192304.
data(dfHRQoL)
dfHRQoL
# Example: construct label + CI text for a table column
with(dfHRQoL,
paste0(sprintf("%.3f", mean),
" [",
sprintf("%.3f", lower),
", ",
sprintf("%.3f", upper), "]")
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.