View source: R/fp_extract_labeltext.R
| fp_extract_labels | R Documentation |
Rebuild label columns on an existing gforge_forestplot object using
selectors mapped in a pipe-friendly style.
fp_extract_labels(x, ..., na = "")
x |
A |
... |
Named mappings where each name is the output label column name and each value is a selector for one source column. |
na |
Replacement value for missing values in atomic scalar cells. |
This helper requires that the plot object was created from a data frame via
forestplot.data.frame() or forestplot.grouped_df() so that source data
are available.
A modified gforge_forestplot object.
data(inventors_vs_mello)
inventors_vs_mello |>
forestplot(mean = est, lower = lb, upper = ub, labeltext = author) |>
fp_extract_labels(Study = author, E1 = ai, N1 = n1i, E2 = ci, N2 = n2i)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.