| fp_span_where | R Documentation |
Apply span attributes to selected cells in a gforge_forestplot object.
fp_span_where(x, columns, rows = NULL, cols = NULL, where = NULL)
x |
A |
columns |
Integer vector of target columns to span. |
rows |
Optional row selector ( |
cols |
Optional column selector ( |
where |
Optional row predicate supplied as a function or one-sided formula,
e.g. |
A modified gforge_forestplot object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.